/*
	Phase II (i.e. Year 1 of Treatment) Implementation Tracking
	
	Author: Gabe Zucker

	Summary: Keeps track of staff movements in order to construct the implement variable (i.e. _impl_c) for the 2sls regressions.
			 Recall inspectors count as 0.4 and constables and clerks count as 0.3. The implement variable is the weighted staff
			 implement in the given quarter divided by the weighted staff implement at the start of the year (i.e. randomization).
			 
			 Implement within a given quarter is given by the state of staff postings by the end of the quarter. Staff movements were
			 manually verified against HR records and coded in Section 4.
			 
			 The globals used here are defined in Master Pakistan Tax Analysis.do.
*/

version 12
clear all
pr drop _all
cap log close
set more off
set mem 300m
*set mat 10000

cap cd "${PAPER_ANALYSIS}"


********************************************************************************************
********************************************************************************************
***2. Input/clean crosswalk, and Q1-Q3 payments and Q1-Q4 tax data, CFW data -> tempfiles***
********************************************************************************************
********************************************************************************************

**Crosswalk
insheet using "${DATA}/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", clear
keep rand* q1_2012_*
tempfile crosswalk
sa `crosswalk', replace
clear


**Subtreatment data for reward rate
use "${PAKTAX_RANDOMIZATION}/Phase II/Randomization/110810 7861 Subreatment Randomization - Copy", clear
replace circle_id=105100 if circle_id==105200   /*!!!*/
keep circle_id rewardrate
tempfile subtreatment
sa `subtreatment', replace



*****************************************************************************************************
*****************************************************************************************************
***3. Input balloted circles; merge with subtreatment, crosswalk, benchmarks and all FY2012 data*****
*****************************************************************************************************
*****************************************************************************************************


***Input original treated circles and H.R. data
use "${PAKTAX_RANDOMIZATION}/Phase II/Randomization/110809 Randomization Output - Additional Circles 999 - Copy", clear
replace treatment=1 if circle_id==105100
replace treatment=0 if circle_id==105200
replace treatment_newballot=0 if circle_id==105200   /*the actual balloted circle is 105100*/
keep if treatment==1 | treatment_newballot==1 /*Only keep the treatment circles*/
keep division_id division_name circle_id inspector_name1-clerk_name1 rewardrate
drop if inlist(circle_id,300800,402100,508700,501000,502800,504902,502200,501500)		// did not consent; from subtreatment randomization file
merge 1:1 circle_id using `subtreatment'
assert _m!=1
keep if _m==3
drop _m


rename circle_id rand_circle_id
merge 1:m rand_circle_id using `crosswalk'
assert _merge!=1	// every circle found itself in the crosswalk
keep if _merge==3
drop _merge
drop rand_circle_*
ren q1_2012_circle_id circle_id
duplicates drop
drop if circle_id==507910 & constable_name1=="STAFF NAME 145"	// this was a merge; the H.R. corrections later fill in the missing H.R. from the kept circle
*Exclude circles where all treated staff left in split/merge
drop if circle_id==612610	
drop if circle_id==105102		
**We are able to do it all in terms of Q1 except for the one split/merge circle.
isid(circle_id)






***don't need constable_name3***
assert constable_name3==""
drop constable_name3







****************************************************************************************************
****************************************************************************************************
***4. Flag individuals who changed during the year**************************************************
****************************************************************************************************
****************************************************************************************************

forv x = 1/4 {
foreach pos in ins_1 ins_2 cons_1 cons_2 clk_1 {
g left_`pos'_Q`x' = 0
la var left_`pos'_Q`x' "`pos' left during Quarter `x'"
}
}

**Q1 post ballot changes**
replace left_ins_1_Q1 = 1 if circle_id==308700 | circle_id==406700 | circle_id==508901 | circle_id==610400 | circle_id==611602 | circle_id==614700 | circle_id==700900 | circle_id==1104200 | circle_id==613810 | circle_id==505500		// removed from this list 308200, T.T. Singh II, b/c guy was actually there the whole time
*no ins_2 changes
replace left_cons_1_Q1=1 if circle_id==406700 | circle_id==406600 | circle_id==506501 | circle_id==611902 | circle_id==507910 | circle_id==801300
replace left_cons_2_Q1=1 if circle_id==408400
replace left_clk_1_Q1=1 if circle_id==205300 | circle_id==400100 | circle_id==400300 | circle_id==508300 | circle_id==511500 | circle_id==611601 | circle_id==611900 | circle_id==615000 | circle_id==614700 | circle_id==800100 | circle_id==900200 | circle_id==506501 | circle_id==808200 | circle_id==1104200 | circle_id==801300

*Also zero out in Q1 if vacant at ballot
qui forv x = 1/5 {
local a : word `x' of ins_1 ins_2 cons_1 cons_2 clk_1
local b : word `x' of inspector_name1 inspector_name2 constable_name1 constable_name2 clerk_name1
replace left_`a'_Q1=1 if `b' == ""		// have to include the fixes done in Q1 changes
}

*Also zero out in Q1 if was an additional charge that we never pay
replace left_ins_1_Q1 = 1 if circle_id==400100	| circle_id==505500


**Q2 post ballot changes**
replace left_ins_1_Q2=1 if inlist(circle_id, 300800, 301800, 401100, 402100, 404400, 504800, 505500, 506502, 508600, 611602, 615000, 801000, 801300, 802500, 803000, 807300, 808200, 808500, 909800, 1104100, 1104200)
replace left_ins_2_Q2=1 if inlist(circle_id,803000,808200)
replace left_cons_1_Q2=1 if inlist(circle_id, 300500, 400100, 402100, 508410, 615000, 801000, 902100)
replace left_cons_2_Q2=1 if inlist(circle_id, 408400,507910)
replace left_clk_1_Q2=1 if inlist(circle_id, 107902, 308700, 402200, 406400, 504800, 505500, 507910, 611000, 611500, 615000, 611900, 611902,  801000, 805600, 809301, 809302, 1000400, 1104200, 900200) 
*Zahra's email on 505500, 507910 and 506501 ^

**Q3 post ballot changes**
replace left_ins_1_Q3=1 if inlist(circle_id, 107300, 107400, 303200, 404400, 505800, 507910, 615000, 700200, 700610, 803000, 807300, 808500, 900100, 900800, 902601, 909800, 1108101)
replace left_ins_2_Q3=1 if inlist(circle_id, 803000, 909800, 808200)
replace left_cons_1_Q3=1 if inlist(circle_id, 507910, 508410, 612510, 801000, 808500, 1005400)
replace left_cons_2_Q3=1 if inlist(circle_id, 909800, 1005700)
replace left_clk_1_Q3=1 if inlist(circle_id, 205300, 303301, 506100, 507910, 508300, 611602, 611902, 615000, 615200, 700610, 801300, 808500, 1000400, 1005400) 

**Q4 post ballot changes**
replace left_ins_1_Q4=1 if inlist(circle_id, 200102,200200,300700,402200,503600,505100,506800,613300,706200,801100,905100,1005400,1101100)
*ins_2 no changes
replace left_cons_1_Q4=1 if inlist(circle_id, 200102,200300,508410,612510,613200,614000,614700,805700,902601,905100)
replace left_cons_2_Q4=1 if inlist(circle_id, 703200)
replace left_clk_1_Q4=1 if inlist(circle_id, 105600,105700,107400,611900,613103,613810,614300,800100,800200,800300,800400,800521,800522,800600,800800,801000,801210,802300,802500,802800,802900,803000,803200,803300,805600,809302,901500,905100,905510) 


g temp = 0
qui forv y = 1/5 {
replace temp = 0
local pos : word `y' of ins_1 ins_2 cons_1 cons_2 clk_1
forv x = 1/4 {
	replace temp = temp + left_`pos'_Q`x'
	replace left_`pos'_Q`x' = 0 if temp>1
	}
**Generate a variable for neverleft
g neverleft_`pos' = 1 if temp ==0
la var neverleft_`pos' "Person in `pos' did not leave during year"
}








****************************************************************************************************
****************************************************************************************************
***5. Calculate fraction of payment by position*****************************************************
****************************************************************************************************
****************************************************************************************************


**Count. checked manually only one change per circle
g count_inspector = 1
replace count_inspector = 2 if left_ins_1_Q1==0 & left_ins_2_Q1==0
g count_constable = 1
replace count_constable = 2 if left_cons_1_Q1==0 & left_cons_2_Q1==0
g count_clerk = 1



*Changes
g count_inspector2 = .
g count_constable2 = .
g change_ins = .
g change_cons = .
forv x = 2/4 {
replace count_inspector2 = 1 if count_inspector==2 & (left_ins_1_Q`x' == 1 | left_ins_2_Q`x'==1) & missing(count_inspector2)
replace change_ins = `x' if count_inspector2==1 & missing(change_ins)
replace count_constable2 = 1 if count_constable==2 & (left_cons_1_Q`x' == 1 | left_cons_2_Q`x'==1) & missing(count_constable2)
replace change_cons = `x' if count_constable2==1 & missing(change_cons)
}
replace count_inspector2 = count_inspector if missing(count_inspector2)
replace count_constable2 = count_constable if missing(count_constable2)


*the ratio is: inspector-40%, constable-30%, and clerk-30%
gen denominator=0.4*count_inspector+0.3*count_constable+0.3*count_clerk
la var denominator "the denominator for payment to each staff member"
gen denominator_2 = .4*count_inspector2 + .3*count_constable2 + .3*count_clerk
la var denominator_2 "denominator 2 if it changes"
g changedenom = .
foreach a in change_ins change_cons {
replace changedenom = `a' if `a' < .
}








****************************************************************************************************
****************************************************************************************************
***6. Implementation Variable***********************************************************************
****************************************************************************************************
****************************************************************************************************

g count_ins_q0 = 2
g count_cons_q0 = 2
g count_clk_q0 = 1
forv x = 1/4 {
local y = `x' - 1
g count_ins_q`x' = count_ins_q`y' - left_ins_1_Q`x' - left_ins_2_Q`x'
g count_cons_q`x' = count_cons_q`y' - left_cons_1_Q`x' - left_cons_2_Q`x'
g count_clk_q`x' = count_clk_q`y' - left_clk_1_Q`x'
}
drop count_*_q0


forv x = 1/4 {
g impl_Q`x' = (count_ins_q`x'*.4 + count_cons_q`x'*.3 + count_clk_q`x' * .3) / denominator
replace impl_Q`x' = (count_ins_q`x'*.4 + count_cons_q`x'*.3 + count_clk_q`x' * .3) / denominator_2 if `x' >= changedenom
}


duplicates drop

keep circle_id impl_*
sort circle_id
saveold "Coded Data/Phase II Balloted Circle HR Change Tracking.dta", replace
