/*
	Phase III (i.e. Year 2 of Treatment) Implementation Tracking and ETO Clsuters
	----------------------------------------------------------------------------------------
	
	Summary: 1) Generates variable (ETO_clus) for clustering supervisor regressions at the ETO level.
	
			 2) Constructs implement variable for staff and circle level treatments (i.e. _impl_c and _impl_s).
			 
			 _impl_c is constructed as in Year 1 of treatment, i.e. we divide the weighted sum of staff presence at the end
			 of a given quarter and divide it by the presence at the beginning of the fiscal year. Note inspectors count as 0.4,
			 constables and clerks count as 0.3.
			 
			 For supervisors, AETO counts as 0.5 and ETO counts as 0.5. The supervisor implement variable is _impl_s and it is
			 orthogonal to _impl_c.
			 
			The globals used here are defined in Master Pakistan Tax Analysis.do.
*/

version 12
clear all
pr drop _all
cap log close
set more off
set mem 300m
*set mat 10000


cap cd "${PAPER_ANALYSIS}"

local ynow 2013
local qnow 4


* Locals for last day of quarter
local day1 = 19266
local day2 = 19358
local day3 = 19448
local day4 = 19539


************************
*** 1. ETO Clusters
************************

* GET RANDOMIZATION DATA FOR TIEBREAKING LATER
u "${PAKTAX_RANDOMIZATION}/ETO & AETO/120707 ETO Randomization Output 6465 - New List - Randomization Circles.dta" 
keep rand_circle_id eto_name
ren rand_circle_id circle_id
ren eto_name orig_name
tempfile randresolve
sa `randresolve'

* CURRENT NET DEMAND DATA FOR TIEBREAKING LATER
u "${DATA}/Cleaned Data/Administrative Data/Punjab Compiled - Quarterly.dta", clear
forv q = 1/`qnow' {
	preserve
		keep if fyear==2013 & qtr==`q'
		keep circle_id net_dem_t
		tempfile netdem`q'
		sa `netdem`q''
	restore
	}

* CROSSWALK
insheet using "${DATA}/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", comma clear
forv q = 1/`qnow' {	
	preserve
		keep rand_circle_id q`q'_2013_circle_id
		drop if q`q'_2013_circle_id==.
		duplicates drop
		tempfile q`q'
		sa `q`q''
	restore
	}

forv q = 1/`qnow' {
	u "${DATA}/Raw Data/Current HR Confirmation/Master Treated Staff (long).dta", clear
	drop if circle_id==.
	g div = floor(circle_id/100000)
	
	* KEEP THE RIGHT ONES
	keep if pos=="eto" & _indate<=`day`q'' & `day`q''<=_outdate
	
	* YOU SHOULD HAVE ONLY ONE; OTHERWISE DOUBLE CHECK CODING FOR CUT-OFF DAYS
	bys circle_id: g temp = _N
	assert temp==1
	drop temp
	keep circle_id div _name
	
	* GIVE THEM NET DEMAND IN CASE NEEDED
	merge 1:1 circle_id using `netdem`q''
	replace _name="VACANT" if _m==2		// these were vacant at end of quarter
	preserve	
		keep if _m==1
		drop _m
		ren circle_id q`q'_2013_circle_id
		merge 1:m q`q'_2013_circle_id using `q`q''
		assert _m!=1
		drop if _m==2
		assert rand_circle_id==.
	restore
	drop if _m==1
	drop _m
	
	* CROSSWALK THEM
	ren circle_id q`q'_2013_circle_id
	merge 1:m q`q'_2013_circle_id using `q`q''
	assert _m==3 if rand_circle_id!=.	// the only messy ones are new circles we don't care about
	keep if _m==3
	drop _m
	drop q`q'_2013_circle_id
	drop if rand_circle_id==.
	ren rand_circle_id circle_id
	
	* FIND CONFLICTS; CROSSWALKING CREATES CONFLICTING CLUSTERS	
	duplicates drop _name circle_id div, force
	duplicates tag circle_id, gen(conflict)
	preserve
		drop if conflict==0
	
	* RECONCILE CONFLICTS: 1. KEEP THE GUY WHO WAS THERE AT RANDOMIZATION, IF HE STILL IS
		merge m:1 circle_id using `randresolve'	// make this tempfile
		assert _m!=1
		drop if _m==2
		drop _m
		g keep1 = _name==orig_name
		bys circle_id: egen resolve1 = max(keep1)
		drop if keep1==0 & resolve1==1
	
	* RECONCILE CONFLICTS: 2. GIVE IT TO THE CLUSTER THAT THE BIGGER CIRCLE WENT TO
		bys circle_id: egen topdemand = max(net_dem_t)
		replace topdemand = round(topdemand)
		drop if resolve1==0 & round(net_dem_t)!=topdemand
		
	* CHECK AND APPEND
		isid circle_id
		drop orig_name resolve1 topdemand net_dem_t conflict keep1
		tempfile resolution
		sa `resolution'
	restore
	keep if conflict==0
	append using `resolution'		
	isid circle_id
	
	* MAKE FINAL GROUPS
	sort circle_id
	egen ETO_clus_q`q' = group(_name div), missing
	keep circle_id ETO_clus*
	
	* INTO TEMPFILE
	if `q'==1 {
		tempfile final
		sa `final'
		}
	else {
		merge 1:1 circle_id using `final'
		assert _m==3
		drop _m
		sa `final', replace
		}
	}

* RESHAPE
reshape long ETO_clus_q, i(circle_id) j(qtr)
ren ETO_clus_q ETO_clus
g fyear=2013
tempfile etoclus
sa `etoclus'




************************
*** 2. _impl Coefficients: circles
************************

* IMPORTANT NOTE: Information circles here are given their true implementation coefficient, which is later renamed to INFO_impl in Phase III Final Coding.
* In that do-file, the _impl_c variable is replaced to 0, because _impl_c is for truly treatment circles; informations are considered control.

* INFORMATION CIRCLES
u "${DATA}/Cleaned Data/Randomization/130506 Cleaned Phase III Randomization.dta", clear
keep if fyear==2013
keep circle_id infotreat2
keep if infotreat2==1
ren infotreat2 information
ren circle_id rand_circle_id
merge 1:m rand_circle_id using `q1'	// assuming things stay constant, can do only to this quarter
assert _m!=1
keep if _m==3
drop _m
keep q1_2013_circle_id information
ren q1_2013_circle_id circle_id
tempfile info
sa `info'

forv q = 1/`qnow' {
	* GET REGULAR CIRCLE TREATS; MERGING INFORMATION
	u "${DATA}/Raw Data/Current HR Confirmation/Master Treated Staff (long).dta", clear
	merge m:1 circle_id using `info'
	assert _m!=2	// won't be the case if there are merge/split issues; would need to deal with it.
	replace information = 0 if information==.
	drop _m
	replace treat=1 if _indate==19181 & information==1	// they are "treated" in information if still there from beginning
	replace subtreatment=4 if information==1	// all circles in information
	keep if subtreatment!=.
	g stafftype = substr(pos,1,3)

	* RATIOS
	g pos_type = substr(position,1,(length(position)-2))
	g pos_ratio = .4 if pos_type=="ins"
	replace pos_ratio = .3 if inlist(pos_type,"cons","clk")
	
	* GEN IMPLEMENT: SUM THIS FOR NUMERATOR
	g implement = pos_ratio
	replace implement = 0 if treat!=1	// remember we've adjusted the treat variable for info people.

	rename position pos
	
	* KEEP RIGHT PEOPLE
	keep if _indate<=`day`q'' & `day`q''<=_outdate
	
	* FIX IT IF WE'RE CATCHING A CHANGE-OVER DAY
	bys circle_id pos: g temp = _N
	drop if `day`q''==_outdate & temp>1
	bys circle_id pos: g temp2 = _N
	assert temp2==1 | treat!=1	// either we've dealt with it or we don't care
	drop temp*
	
	* STAFF DENOMINATOR
	preserve
		drop if inlist(pos,"aeto","eto")
		bys circle_id pos_type: g staffnum = _N
		g addon1 = pos_ratio if staffnum==2
		bys circle_id: egen addon2 = total(addon1)
		g denominator = 1+(addon2/2)
		ta denominator
		assert denominator!=.
		keep circle_id denominator
		duplicates drop
		tempfile denom
		sa `denom'
	restore
	merge m:1 circle_id using `denom'
	assert _m==3 if subtreatment!=.
	drop _m

	* RATIO
	bys circle_id: egen implement_num = total(implement)
	g _impl_q`q' = (implement_num/denominator)
	assert _impl_q`q'!=.
	
	keep circle_id _impl_q`q'
	duplicates drop
		
	* CROSSWALK THEM
	ren circle_id q`q'_2013_circle_id
	merge 1:m q`q'_2013_circle_id using `q`q''
	assert _m!=1
	drop if _m==2
	drop _m
	drop q`q'_2013_circle_id
	drop if rand_circle_id==.
	ren rand_circle_id circle_id
	
	* RECONCILE CONFLICTS
	duplicates drop
	duplicates tag circle_id, gen(temp)
	count if temp!=0
	local a = `r(N)'/2
	di "There are `a' duplicate cases; these are reconciled as averages. Line 312."
	
	replace _impl_q`q' = 0 if _impl_q`q'==. & temp!=0
	drop temp
	bys circle_id: egen temp = mean(_impl_q`q')
	replace _impl_q`q' = temp
	drop temp
	duplicates drop
	isid circle_id
		
	* INTO TEMPFILE
	if `q'==1 {
		tempfile final
		sa `final'
		}
	else {
		merge 1:1 circle_id using `final'
		count if _m!=3
		assert `r(N)'==1	// this is 802400, because it was only a circle treatment circle once!
		drop _m
		sa `final', replace
		}
	}

* RESHAPE
reshape long _impl_q, i(circle_id) j(qtr)
ren _impl_q _impl_c
g fyear=2013
tempfile circleimpl
sa `circleimpl'





************************
*** 3. _impl Coefficients: supervisors
************************
forv q = 1/`qnow' {
	* GET REGULAR CIRCLE TREATS; MERGING ININFORMATION
	u "${DATA}/Raw Data/Current HR Confirmation/Master Treated Staff (long).dta", clear
	keep if treat_eto==1

	* GEN IMPLEMENT: SUM THIS FOR NUMERATOR
	g implement = .5
	replace implement = 0 if treat!=1

	* KEEP RIGHT PEOPLE
	keep if _indate<=`day`q'' & `day`q''<=_outdate
	
	* FIX IT IF WE'RE CATCHING A CHANGE-OVER DAY
	bys circle_id pos: g temp = _N
	drop if `day`q''==_outdate & temp>1
	bys circle_id pos: g temp2 = _N
	assert temp2==1 | treat!=1	// it's fine, or we don't care anyway
	drop temp*
		
	* RATIO
	bys circle_id: egen _impl_q`q' = total(implement)
	assert _impl_q`q'!=.
	keep circle_id _impl_q`q'
	duplicates drop
		
	* CROSSWALK THEM
	ren circle_id q`q'_2013_circle_id
	merge 1:m q`q'_2013_circle_id using `q`q''
	assert _m!=1
	drop if _m==2
	drop _m
	drop q`q'_2013_circle_id
	drop if rand_circle_id==.
	ren rand_circle_id circle_id
	
	* RECONCILE CONFLICTS
	duplicates drop
	duplicates tag circle_id, gen(temp)
	count if temp!=0
	local a = `r(N)'/2
	di "There are `a' duplicate cases; these are reconciled as averages. Line 389."
	replace _impl_q`q'=0 if _impl_q`q'==. & temp!=.
	drop temp
	bys circle_id: egen temp = mean(_impl_q`q')
	replace _impl_q`q' = temp
	drop temp
	duplicates drop
	isid circle_id
		
	* INTO TEMPFILE
	if `q'==1 {
		tempfile final
		sa `final'
		}
	else {
		merge 1:1 circle_id using `final'
		assert _m==3
		drop _m
		sa `final', replace
		}
	}

* RESHAPE
reshape long _impl_q, i(circle_id) j(qtr)
ren _impl_q _impl_s
g fyear=2013
tempfile superimpl
sa `superimpl'




************************
*** 4. Merge
************************

u `etoclus', clear
merge 1:1 circle_id fyear qtr using `circleimpl'
assert _m!=2
drop _m
merge 1:1 circle_id fyear qtr using `superimpl'
assert _m!=2
drop _m

sort circle_id fyear qtr
saveold "Coded Data/Phase III ETO Clusters and Implementation.dta", replace
