/*******************************************************************************
REVENUE
Impacts on Revenue Collected

Kunal Mangal
April 8 2014

SUMMARY: Main revenue outcomes. Current, Arrears, and Totals for both years of the experiment.
Treatments pooled and separately by subtreatment.

*******************************************************************************/
version 12
clear all
set more off

cap cd "${PAPER_ANALYSIS}"
do "Do Files/Paper/programs/all_programs.do"

** REGRESSIONS *****************************************************************

use "Coded Data/Phase III Analysis Data.dta", clear
	
forv y = 1/2 {

	local year : word `y' of 2012 2013
	local phase : word `y' of II III

	label var _impl_c "Any treatment"
	label var REV_impl "Revenue"
	label var REVPLS_impl "Revenue Plus"
	label var CFW_impl "Flexible Bonus"
	label var INFO_impl "Information"

	forv z = 1/3 {
		local x : word `z' of t c a
		
		* Regress - Main Treatment - Panel A
		eststo `phase'_`x'_A : ///
		  ivreg ln_recov_tot_`x' base_ln_recov_tot_`x' (_impl_c =_select_c) ///
			stratdum_c* if fyear==`year' & qtr == 4, cluster(cluster_c)
	
		qui sum ln_recov_tot_`x' if e(sample) == 1 & _select_c == 0
		estadd scalar ymean = `r(mean)'			
		
		* Regress - Subtreatments - Panel B

		eststo `phase'_`x'_B : ///
		  ivreg ln_recov_tot_`x' base_ln_recov_tot_`x' ///
			(REV_impl REVPLS_impl CFW_impl ///
			= REV_sel REVPLS_sel CFW_sel) stratdum_c* ///
			if fyear==`year' & qtr==4, cluster(cluster_c)
	  
		qui sum ln_recov_tot_`x' if e(sample) == 1 & _select_c == 0
		estadd scalar ymean = `r(mean)'	
	
		estadd joint REV_impl REVPLS_impl CFW_impl : `phase'_`x'_B 
		estadd equivalence REV_impl REVPLS_impl CFW_impl: `phase'_`x'_B
		estadd eqavg REV_impl REVPLS_impl CFW_impl, prefix(rvm_): `phase'_`x'_B
		estadd eqavg CFW_impl REV_impl REVPLS_impl, prefix(ovs_): `phase'_`x'_B
		 
		eststo `phase'_`x' : combine_models2 `phase'_`x'_A `phase'_`x'_B, headings(A B)
	}
}

** TeX OUTPUT ******************************************************************

# delimit ;
esttab II_t II_c II_a III_t III_c III_a
	using "${TABLE_OUTPUT}/tex/input/revenue_infocontrol_input.tex", 
	keep(_impl_c REV_impl REVPLS_impl CFW_impl)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("Total" "Current" "Arrears" "Total" "Current" "Arrears") // Column headings
	
	eqlabels(
		//Embed latex code into the labels (emphasis)
		"\emph{Panel A: Main Treatment}"
		"\emph{Panel B: Subtreatments}"
		
		//prefix is added before every eqlabel, and suffix after every exlabel. 
		//Span forces column to span across rows, and @span is the width of the table
		// \addlinespace[1mm] adds extra space before table row. 
		prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
	)
		
	//nonumbers // No column numbers
	
	stats(N2 ymean2 rvm_eqavg2 ovs_eqavg2 equivalence2 joint2,
		labels(
			"N"
			"Mean of control group"
			"Rev. vs. Multitasking p."
			"Objective vs. Subjective p."
			"Equality of Schemes"
			"Joint significance"
		)	
		fmt(
			"%12.0f" "%12.3f" "%12.3f" "%12.3f" "%12.3f" "%12.3f"
		)
	)

	mgroups("Year 1" "Year 2",
		pattern(1 0 0 1 0 0)
		prefix(\multicolumn{@span}{c}{)
		suffix(}) span erepeat(\cmidrule(lr){@span})
	)
	
	label // Use Variable Labels
	
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr
eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off
local file revenue_infocontrol

** WRITE TABLE NOTE
/*
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "Instrumental variables regressions, where treatment status is instrumented with randomization results."
file write tablenote " The unit of observation is a circle, as defined at the time of randomization."
file write tablenote " Outcome variable is log revenue collection as of the end of the fiscal year,"
file write tablenote " for total revenue (Columns 1 and 4), current year revenue (Columns 2 and 5), and collections against arrears (columns 3 and 6)."
file write tablenote " Specification follows Equation 5.3 of the main text, and includes stratum fixed effects."
file write tablenote " 'Any treatment' in Panel A includes the 3 subtreatments in Panel B."
file write tablenote " The Information treatment is included in the controls."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Standard errors are clustered by a robust partition of circles,"
file write tablenote " the group of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote
*/

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 

cap log close
