/*******************************************************************************
WHO GETS RE-ASSESSED
Selection Effects into Section 9 by Treatment

Panel A - selection effects by treatment into Section 9 for property characteristics
Panel B - selection effects for property characteristics

Wayne Aaron Sandholtz
27 January 2014

*******************************************************************************/
version 12
clear all
set more off
set matsize 800

cap cd "${PAPER_ANALYSIS}"
do "Do Files/Paper/programs/all_programs.do"

** PREP ************************************************************************

** DEFINE VARIABLE LISTS
#delimit ;
	
global panela
	GARV
	floors
	last_renovation2
	land_area
	tot_cov_area
	main_road
	category_scale
	pctcom
	pctcomrent
	tax_liability
	;
	
global panelb
	age
	educ_yrs
	wages
	expenditure_hat
	connect_political
	connect_pgp
	;	
#delimit cr

**************************************************************

** USE DATA
use "Coded Data/survey_coded_data.dta", clear
			
** LABEL VARIABLES
la var _impl_c_xw "Treatment"
la var SEC9 "Re-assess"
la var SEC9_impl_c_xw "Re-assess * Treatment"

foreach x in a b {
	foreach var in ${panel`x'}{
		eststo `var': ///
		  ivreg `var' (SEC9_impl_c_xw = SEC9_select_c_xw) ///
		    SEC9 short_dummy circlefe* , cluster(cluster_c)
		
		qui sum `var' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
		estadd scalar ysumm = `r(mean)'
	}
}


** TeX output, Panel A *********************************************************


# delimit ;
esttab $panela
	using "${TABLE_OUTPUT}/tex/input/sec9_selection_main_infocontrol_a_input.tex", 
	keep(SEC9_impl_c_xw SEC9)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles(
		"\specialcell{GARV}"
		"\specialcell{Number of \\ floors}"
		"\specialcell{Last \\ renovation \\ was $\leq$ 2 \\ years ago}"
		"\specialcell{Land area \\ (sq. feet)}"
		"\specialcell{Total \\ covered area \\ (sq. feet)}"
		"\specialcell{Main \\ Road}"
		"\specialcell{Tax Category}"
		"\specialcell{Percent of \\ property \\ commercial}"
		"\specialcell{Percent of \\ property \\ commercial \\ and rented}"
		"\specialcell{Tax \\ Liability}"
		) // Column headings
	
	stats(N ysumm,
		labels(
			"N"
			"\specialcellleft{Mean of \\ control group \\ in gen. pop. sample}"
		)	
		fmt(
			"%12.0f" "%12.2f"
		)
	)

	
	mgroups(" " "Components of GARV" "",
		pattern(1 0 0 1 0 0 0 0 0 1)
		prefix(\multicolumn{@span}{c}{)
		suffix(}) span erepeat(\cmidrule(lr){@span})
	)
	
	
	label // Use Variable Labels
	nonotes	
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	replace
	;

# delimit cr

** TeX output, Panel C *********************************************************

# delimit ;
esttab $panelb
	using "${TABLE_OUTPUT}/tex/input/sec9_selection_main_infocontrol_b_input.tex", 
	keep(SEC9_impl_c_xw SEC9)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles(
		"\specialcell{Approximate \\ age of owner}"
		"\specialcell{Owner's level \\ of education}"
		"\specialcell{Per-capita \\ wages}"
		"\specialcell{Predicted \\ expenditure \\ given assets}"
		"\specialcell{Connected \\ to Politician}"
		"\specialcell{Connected \\ to Politician/ \\ Government/ \\ Police}"
	) // Column headings
	
	/*
	eqlabels(
		//Embed latex code into the labels (emphasis)
		"\emph{Panel A: Main Treatment}"
		"\emph{Panel B: Subtreatments}"
		
		//prefix is added before every eqlabel, and suffix after every exlabel. 
		//Span forces column to span across rows, and @span is the width of the table
		// \addlinespace[1mm] adds extra space before table row. 
		prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
	)
	*/	
	
	stats(N ysumm,
		labels(
			"N"
			"\specialcellleft{Mean of \\ control group \\ in gen. pop. sample}"
		)	
		fmt(
			"%12.0f" "%12.2f"
		)
	)

	/*
	mgroups("Year 1" "Year 2",
		pattern(1 0 0 1 0 0)
		prefix(\multicolumn{@span}{c}{)
		suffix(}) span erepeat(\cmidrule(lr){@span})
	)
	*/
	
	label // Use Variable Labels
	
	nonotes
	
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr

eststo clear

** WRITE LaTeX WRAPPER *********************************************************

set more off
local file sec9_selection_main_infocontrol


** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "Property level 2SLS regressions. Specifications follow Equation 5.6 of the main text, and includes a control for"
file write tablenote " whether the response came from the short version of the questionnaire."
file write tablenote " Panel A looks at selection effects on property characteristics and Panel B looks at selection effects on owner/tenant characteristics. The characteristics in Panel A labeled Components of GARV"
file write tablenote " are those that directly enter into the formula used to calculate GARV. Tax Category (Panel A, Column 7) is 7-tiered categorical variable"
file write tablenote " with 7 being the most expensive tax bracket and 1 being the cheapest."
file write tablenote " Per-capita wages (Panel B, Column 3) is self-reported household expenditures divided by the total number of working household members."
file write tablenote " Predicted expenditure given assests (Panel B, Column 4) is the predicted value of a regression of household expenditure on series of dummy variables indicating various household assets."
file write tablenote " Standard errors in all panels are clustered by robust partition,"
file write tablenote " the partition of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote


file open tablenotefile using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", read
file read tablenotefile noteline


** Write the file **********************************************************
# delimit ;
cap file close x;
file open x using "${TABLE_OUTPUT}/tex/`file'.tex" ///
  , write replace;
foreach thing in 
`"\documentclass[preview, varwidth=8.25in, border=10pt]{standalone} 	"'
`"\usepackage{amsmath}                                                  "'
`"\usepackage{amsfonts}                                                 "'
`"\usepackage{booktabs}                                                 "'
`"\usepackage{threeparttable}                                           "'
`"\usepackage{titlesec}                                                 "'
`"                                                                      "'
`"% This is for word wrap in cells in tables.                           "'
`"\newcommand{\specialcell}[2][c]{%                                     "'
`"\begin{tabular}[#1]{@{}c@{}}#2\end{tabular}}                          "'
`"\newcommand{\specialcellleft}[2][l]{%                                     "'
`"\begin{tabular}[#1]{@{}l@{}}#2\end{tabular}}                          "'
`"                                                                      "'
`"\titleformat{\section}                                                "'
`"  {\normalfont\scshape}{\thesection}{1em}{}                           "'
`"                                                                      "'
`"\begin{document}                                                      "'
`"\begin{table}[htp]                                                    "'
`"\scriptsize                                                           "'
`"\emph{Panel A}\\"'
`"\input{"input/`file'_a_input.tex"}		                           	"'
`"\end{table}                                                           "'
`"\begin{table}[htp]                                                    "'
`"\scriptsize                                                           "'
`"\emph{Panel B}\\"'
`"\begin{threeparttable}												"'
`"\begin{tabular}{l*{6}{c}}									            "'
`"\toprule																"'
`"\input{"input/`file'_b_input.tex"}		                          	"'
`"\bottomrule															"'
`"\end{tabular}														    "'
`"\end{threeparttable} \\													"'
`"\scriptsize \emph{Notes}: `noteline'							"'
`"\end{table}                                                           "'
`"\end{document}                                                        "'{;
	file write x `"`thing'"' _n;
};
file close x;
# delimit cr
****************************************************************************

file close tablenotefile

** COMPILE *********************************************************************

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
	

cap log close
