/*******************************************************************************
WHO GETS RE-ASSESSED
Impacts on Reassessments

Panel A - number of new and reassessed properties
Panel B - selection effects by treatment into Section 9 for property characteristics
Panel C - selection effects for property characteristics

Wayne Aaron Sandholtz
27 January 2014

*******************************************************************************/
version 12
clear all
set more off
set matsize 800

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** PREP ************************************************************************

** DEFINE VARIABLE LISTS
#delimit ;

global panela
	total
	new
	reassess
	;
	
global panelb
	GARV
	floors
	last_renovation2
	land_area
	tot_cov_area
	main_road
	category_scale
	pctcom
	pctcomrent
	tax_liability
	;
	
global panelc
	age
	educ_yrs
	wages
	expenditure_hat
	connect_political
	connect_pgp
	;	
#delimit cr

** PANEL A *********************************************************************

** USE DATA
u "${DATA}/Cleaned Data/Field Survey/Round 3/Cleaned/Sec9_Title_Count.dta", clear

** GENERATE NEW VARIABLES
gen new_y2 = S9TITLE_q4a + S9TITLE_q5a
gen new_y1 = S9TITLE_q6a + S9TITLE_q7a
gen new_y0 = S9TITLE_q9a + S9TITLE_q10a

gen new = new_y2 + new_y1

gen reassess_y2 = S9TITLE_q4b + S9TITLE_q5b
gen reassess_y1 = S9TITLE_q6b + S9TITLE_q7b
gen reassess_y0 = S9TITLE_q9b + S9TITLE_q10b

gen reassess = reassess_y2 + reassess_y1

gen total_y2 = new_y2 + reassess_y2
gen total_y1 = new_y1 + reassess_y1
gen total_y0 = new_y0 + reassess_y0

gen total = total_y2 + total_y1

merge m:1 circle_id using "Coded Data/Survey Circle Clusters"
assert _merge == 3 if !inlist(circle_id, 400400, 402502, 506901, 507100, 800521)
drop _merge

* Fixing the circle coding problem
replace circle_id = 612200 if circle_name == "MODEL TOWN-EXT-I"
replace circle_id = 612300 if circle_name == "MODEL TOWN-EXT-II"

* Merge in Treatment Variables
merge m:1 circle_id using "Coded Data/Survey Treatment Variables"
assert _merge == 3
drop _merge

label var _impl_c_xw "Treatment"

** REGRESSIONS *****************************************************************

foreach var in	$panela {

	eststo `var': ///
	  ivreg `var' (_impl_c_xw = _select_c_xw) reassess_y0 new_y0 stratdum_c*, cluster(cluster_c)
	
	qui sum `var'_y2 if e(sample) == 1 & _select_c_xw == 0
	estadd scalar ysumm = `r(mean)' 	

	}
	
** TeX output, Panel A *********************************************************

# delimit ;
esttab $panela
	using "${TABLE_OUTPUT}/tex/input/who_gets_reassessed_main_infocontrol_a_input.tex", 
	keep(_impl_c_xw)
	
	b(%12.1f)
	se(%12.2f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles(
		"\specialcell{Total Number of Section 9 Properties \\ Added to Tax Rolls \\ in Treatment Period}"
		"\specialcell{Number of New Properties \\ Added to Tax Rolls \\ in Treatment Period}"
		"\specialcell{Number of Reassessed Properties \\ Added to Tax Rolls \\ in Treatment Period}"
	) // Column headings
	
	/*
	eqlabels(
		//Embed latex code into the labels (emphasis)
		"\emph{Panel A: Main Treatment}"
		"\emph{Panel B: Subtreatments}"
		
		//prefix is added before every eqlabel, and suffix after every exlabel. 
		//Span forces column to span across rows, and @span is the width of the table
		// \addlinespace[1mm] adds extra space before table row. 
		prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
	)
	*/	
	
	stats(N ysumm,
		labels(
			"N"
			"Mean of control group"
		)	
		fmt(
			"%12.0f" "%12.1f"
		)
	)
	
	label // Use Variable Labels
	
	nonotes
	
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	replace
	;

# delimit cr

eststo clear



** PANEL B, PANEL C ************************************************************

local _sec9 = "_sec9"
local SEC9 = "SEC9"
local SEC9_sel = "SEC9_select_c_xw"
local SEC9_impl = "SEC9_impl_c_xw"
local SEC9_sel_subs = "SEC9REV_sel_xw SEC9REVPLS_sel_xw SEC9CFW_sel_xw"
local SEC9_impl_subs = "SEC9REV_impl_xw SEC9REVPLS_impl_xw SEC9CFW_impl_xw"

** USE DATA
use "Coded Data/survey_coded_data.dta", clear
			
** LABEL VARIABLES
la var _impl_c_xw "Treatment"
la var SEC9 "Re-assess"
la var SEC9_impl_c_xw "Re-assess * Treatment"

foreach x in b c {
	foreach var in ${panel`x'}{
		eststo `var': ///
		  ivreg `var' (SEC9_impl_c_xw = SEC9_select_c_xw) ///
		    SEC9 short_dummy circlefe* , cluster(cluster_c)
		
		qui sum `var' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0
		estadd scalar ysumm = `r(mean)'
	}
}


** TeX output, Panel B *********************************************************


# delimit ;
esttab $panelb
	using "${TABLE_OUTPUT}/tex/input/who_gets_reassessed_main_infocontrol_b_input.tex", 
	keep(SEC9_impl_c_xw SEC9)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles(
		"\specialcell{GARV}"
		"\specialcell{Number of \\ floors}"
		"\specialcell{Last \\ renovation \\ was $\leq$ 2 \\ years ago}"
		"\specialcell{Land area \\ (sq. feet)}"
		"\specialcell{Total \\ covered area \\ (sq. feet)}"
		"\specialcell{Main \\ Road}"
		"\specialcell{Tax Category}"
		"\specialcell{Percent of \\ property \\ commercial}"
		"\specialcell{Percent of \\ property \\ commercial \\ and rented}"
		"\specialcell{Tax \\ Liability}"
		) // Column headings
	
	/*
	eqlabels(
		//Embed latex code into the labels (emphasis)
		"\emph{Panel A: Main Treatment}"
		"\emph{Panel B: Subtreatments}"
		
		//prefix is added before every eqlabel, and suffix after every exlabel. 
		//Span forces column to span across rows, and @span is the width of the table
		// \addlinespace[1mm] adds extra space before table row. 
		prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
	)
	*/	
	
	stats(N ysumm,
		labels(
			"N"
			"\specialcellleft{Mean of \\ control group \\ in gen. pop. sample}"
		)	
		fmt(
			"%12.0f" "%12.2f"
		)
	)

	
	mgroups(" " "Components of GARV" "",
		pattern(1 0 0 1 0 0 0 0 0 1)
		prefix(\multicolumn{@span}{c}{)
		suffix(}) span erepeat(\cmidrule(lr){@span})
	)
	
	
	label // Use Variable Labels
	nonotes	
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	replace
	;

# delimit cr

** TeX output, Panel C *********************************************************

# delimit ;
esttab $panelc
	using "${TABLE_OUTPUT}/tex/input/who_gets_reassessed_main_infocontrol_c_input.tex", 
	keep(SEC9_impl_c_xw SEC9)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles(
		"\specialcell{Approximate \\ age of owner}"
		"\specialcell{Owner's level \\ of education}"
		"\specialcell{Per-capita \\ wages}"
		"\specialcell{Predicted \\ expenditure \\ given assets}"
		"\specialcell{Connected \\ to Politician}"
		"\specialcell{Connected \\ to Politician/ \\ Government/ \\ Police}"
	) // Column headings
	
	/*
	eqlabels(
		//Embed latex code into the labels (emphasis)
		"\emph{Panel A: Main Treatment}"
		"\emph{Panel B: Subtreatments}"
		
		//prefix is added before every eqlabel, and suffix after every exlabel. 
		//Span forces column to span across rows, and @span is the width of the table
		// \addlinespace[1mm] adds extra space before table row. 
		prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
	)
	*/	
	
	stats(N ysumm,
		labels(
			"N"
			"\specialcellleft{Mean of \\ control group \\ in gen. pop. sample}"
		)	
		fmt(
			"%12.0f" "%12.2f"
		)
	)

	/*
	mgroups("Year 1" "Year 2",
		pattern(1 0 0 1 0 0)
		prefix(\multicolumn{@span}{c}{)
		suffix(}) span erepeat(\cmidrule(lr){@span})
	)
	*/
	
	label // Use Variable Labels
	
	nonotes
	
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr

eststo clear

** WRITE LaTeX WRAPPER *********************************************************

set more off
local file who_gets_reassessed_main_infocontrol

/*
** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "Panel A - Circle-level 2SLS regressions. Sample consists of Phase 2 circles."
file write tablenote " Specification includes stratum fixed effects and controls for number of new and reassessed properties added"
file write tablenote " in the pre-treatment (FY 2011) fiscal year."
file write tablenote " Panels B and C - Property level 2SLS regressions. Specifications follow Equation 5.6 of the main text, and includes a control for"
file write tablenote " whether the response came from the short version of the questionnaire."
file write tablenote " Panel B looks at selection effects on property characteristics and Panel C looks at selection effects on owner/tenant characteristics. The characteristics in Panel B labeled Components of GARV"
file write tablenote " are those that directly enter into the formula used to calculate GARV. Tax Category (Panel B, Column 7) is 7-tiered categorical variable"
file write tablenote " with 7 being the most expensive tax bracket and 1 being the cheapest."
file write tablenote " Per-capita wages (Panel C, Column 3) is self-reported household expenditures divided by the total number of working household members."
file write tablenote " Predicted expenditure given assests (Panel C, Column 4) is the predicted value of a regression of household expenditure on series of dummy variables indicating various household assets."
file write tablenote " Standard errors in all panels are clustered by robust partition,"
file write tablenote " the partition of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote
*/

file open tablenotefile using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", read
file read tablenotefile noteline


** Write the file **********************************************************
# delimit ;
cap file close x;
file open x using "${TABLE_OUTPUT}/tex/`file'.tex" ///
  , write replace;
foreach thing in 
`"\documentclass[preview, varwidth=8.25in, border=10pt]{standalone} 	"'
`"\usepackage{amsmath}                                                  "'
`"\usepackage{amsfonts}                                                 "'
`"\usepackage{booktabs}                                                 "'
`"\usepackage{threeparttable}                                           "'
`"\usepackage{titlesec}                                                 "'
`"                                                                      "'
`"% This is for word wrap in cells in tables.                           "'
`"\newcommand{\specialcell}[2][c]{%                                     "'
`"\begin{tabular}[#1]{@{}c@{}}#2\end{tabular}}                          "'
`"\newcommand{\specialcellleft}[2][l]{%                                     "'
`"\begin{tabular}[#1]{@{}l@{}}#2\end{tabular}}                          "'
`"                                                                      "'
`"\titleformat{\section}                                                "'
`"  {\normalfont\scshape}{\thesection}{1em}{}                           "'
`"                                                                      "'
`"\begin{document}                                                      "'
`"\begin{table}[htp]                                                    "'
`"\scriptsize                                                           "'
`"\emph{Panel A}\\"'
`"\input{"input/`file'_a_input.tex"}		                           	"'
`"\end{table}                                                           "'
`"\begin{table}[htp]                                                    "'
`"\scriptsize                                                           "'
`"\emph{Panel B}\\"'
`"\input{"input/`file'_b_input.tex"}		                           	"'
`"\end{table}                                                           "'
`"\begin{table}[htp]                                                    "'
`"\scriptsize                                                           "'
`"\emph{Panel C}\\"'
`"\begin{threeparttable}												"'
`"\begin{tabular}{l*{6}{c}}									            "'
`"\toprule																"'
`"\input{"input/`file'_c_input.tex"}		                          	"'
`"\bottomrule															"'
`"\end{tabular}														    "'
`"\end{threeparttable} \\													"'
`"\scriptsize \emph{Notes}: `noteline'							"'
`"\end{table}                                                           "'
`"\end{document}                                                        "'{;
	file write x `"`thing'"' _n;
};
file close x;
# delimit cr
****************************************************************************

file close tablenotefile

** COMPILE *********************************************************************

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
	

cap log close
