/*******************************************************************************
REVENUE - Information Treatment OUT of controls
Impacts on Revenue Collected, Separating Information Treatment

Kunal Mangal
April 8 2014

*******************************************************************************/
version 12
clear all
set more off

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** REGRESSIONS *****************************************************************

use "Coded Data/Phase III Analysis Data.dta", clear

label var _impl_c "Any treatment"
label var REV_impl "Revenue"
label var REVPLS_impl "Revenue Plus"
label var CFW_impl "Flexible Bonus"
label var INFO_impl "Information"

forv y = 1/2 {

	local year : word `y' of 2012 2013
	local phase : word `y' of II III
	
	if `year' == 2013 {
		local a "INFO_impl"
		local b "INFO_sel"
	}
	else {
		local a ""
		local b ""
	}
	
	forv z = 1/3 {
		local x : word `z' of t c a
			
		* Regress - Main Treatment - Panel A
		eststo `phase'_`x'_A : ///
		  ivreg ln_recov_tot_`x' base_ln_recov_tot_`x' (_impl_c `a' =_select_c `b') ///
		    stratdum_c* if fyear==`year' & qtr == 4, cluster(cluster_c)
		
		qui sum ln_recov_tot_`x' if e(sample) == 1 & _select_c == 0 & INFO_sel == 0
		estadd scalar ymean = `r(mean)'				  

		
		* Regress - Subtreatments - Panel B
					
		eststo `phase'_`x'_B : ///
		  ivreg ln_recov_tot_`x' base_ln_recov_tot_`x' ///
		    (REV_impl REVPLS_impl CFW_impl `a' ///
		    = REV_sel REVPLS_sel CFW_sel `b') stratdum_c* ///
		    if fyear==`year' & qtr==4, cluster(cluster_c)
		  
		qui sum ln_recov_tot_`x' if e(sample) == 1 & _select_c == 0 & INFO_sel == 0
		estadd scalar ymean = `r(mean)'	
		
		estadd joint REV_impl REVPLS_impl CFW_impl : `phase'_`x'_B 
		estadd equivalence REV_impl REVPLS_impl CFW_impl: `phase'_`x'_B
		estadd eqavg REV_impl REVPLS_impl CFW_impl, prefix(rvm_): `phase'_`x'_B
		estadd eqavg CFW_impl REV_impl REVPLS_impl, prefix(ovs_): `phase'_`x'_B
		 
		eststo `phase'_`x' : combine_models2 `phase'_`x'_A `phase'_`x'_B, headings(A B)
	}
}

** TeX OUTPUT ******************************************************************

# delimit ;
esttab II_t II_c II_a III_t III_c III_a
	using "${TABLE_OUTPUT}/tex/input/revenue_infoout_input.tex", 
	keep(_impl_c REV_impl REVPLS_impl CFW_impl INFO_impl)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("Total" "Current" "Arrears" "Total" "Current" "Arrears") // Column headings
	
	eqlabels(
		//Embed latex code into the labels (emphasis)
		"\emph{Panel A: Main Treatment}"
		"\emph{Panel B: Subtreatments}"
		
		//prefix is added before every eqlabel, and suffix after every exlabel. 
		//Span forces column to span across rows, and @span is the width of the table
		// \addlinespace[1mm] adds extra space before table row. 
		prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
	)
		
	//nonumbers // No column numbers
	
	stats(N2 ymean2 rvm_eqavg2 ovs_eqavg2 equivalence2 joint2,
		labels(
			"N"
			"Mean of control group"
			"Rev. vs. Multitasking p."
			"Objective vs. Subjective p."
			"Equality of Schemes"
			"Joint significance"
		)	
		fmt(
			"%12.0f" "%12.3f" "%12.3f" "%12.3f" "%12.3f" "%12.3f"
		)
	)

	mgroups("Year 1" "Year 2",
		pattern(1 0 0 1 0 0)
		prefix(\multicolumn{@span}{c}{)
		suffix(}) span erepeat(\cmidrule(lr){@span})
	)
	
	label // Use Variable Labels
	
	nonotes
	
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr
eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off
local file revenue_infoout

** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "This table re-estimates Table 3 from the main text, separating the Information treatment from the control group. See Notes to Table 3 for additional information."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 

cap log close
