/*******************************************************************************
INSPECTOR BELIEFS

Beliefs on future rewards / probability of selection in future ballots
by treatment

Kunal Mangal
18 April 2014

*******************************************************************************/
version 12
clear all
set more off

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

************************************

u "${DATA}/Cleaned Data/Inspector Survey/Inspector Survey Clean.dta", clear

merge 1:1 circle_id using "Coded Data/Inspector Treatment Variables"
list circle_id if _merge == 1, clean
count if _merge == 1
keep if _m == 3
drop _m

merge 1:1 circle_id using "Coded Data/Inspector Circle Clusters.dta"
keep if _merge == 3
drop _merge

** MAIN EFFECT *****************************************************************

#delimit ;
local variables
	reward_chance
	;
#delimit cr

label var _impl_c_xw "Any treatment"
label var REV_impl_xw "Revenue"
label var REVPLS_impl_xw "Revenue Plus"
label var CFW_impl_xw "Flexible Bonus"
label var INFO_impl_xw "Information"

label var REV_sel_xw "Revenue"
label var REVPLS_sel_xw "Revenue Plus"
label var CFW_sel_xw "Flexible Bonus"
label var INFO_sel_xw "Information"

replace chance_inc = 4 - chance_inc
replace chance_con = 4 - chance_con

eststo mod1 : oprobit reward_chance INFO_sel_xw if _select_c_xw == 0, cl(cluster_c)

estadd local omit = "Control"

qui sum reward_chance if e(sample) == 1 & INFO_sel_xw == 0
estadd scalar ymean = `r(mean)'

eststo mod2 : oprobit chance REV_sel_xw REVPLS_sel_xw CFW_sel_xw INFO_sel_xw, cl(cluster_c)

estadd local omit = "Control"

qui sum chance if e(sample) == 1 & INFO_sel_xw == 0
estadd scalar ymean = `r(mean)'

eststo mod3 : oprobit chance_inc INFO_sel_xw if _select_c_xw == 0, cl(cluster_c)

estadd local omit = "Control"

qui sum chance_inc if e(sample) == 1 & INFO_sel_xw == 0
estadd scalar ymean = `r(mean)'

eststo mod4 : oprobit chance_con REVPLS_sel_xw CFW_sel_xw INFO_sel_xw if _select_c_xw > 0 | INFO_sel_xw > 0, cl(cluster_c)

estadd local omit = "Revenue"

qui sum chance_con if e(sample) == 1 & REV_sel_xw == 1
estadd scalar ymean = `r(mean)'

** TeX OUTPUT ******************************************************************
# delimit ;
esttab mod1 mod2 mod3 mod4  
	using "${TABLE_OUTPUT}\tex\input\inspector_chances_oprobit_input.tex", 
	keep(REV_sel_xw REVPLS_sel_xw CFW_sel_xw INFO_sel_xw)
	order(INFO_sel_xw REV_sel_xw REVPLS_sel_xw CFW_sel_xw)
	
	b(%12.3g)
	se(%12.3g)
		
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles(
	"\specialcell{Chance of being rewarded \\ after 2012 ballot}"
	"\specialcell{Chance of being selected \\ in 2013 ballot}"
	"\specialcell{Chance of being selected \\ in 2013 ballot relative \\ to incentive circles}"
	"\specialcell{Chance of being selected \\ in 2013 ballot relative \\ to control circles}"
	  ) // Column headings
		
	stats(N omit ymean,
		labels(
			"N"
			"Omitted group"
			"Mean of omitted group"
		)	
		fmt(
			"%12.0f" "a3" "%12.2f"
		)
	)
	
	label // Use Variable Labels
	
	nonotes
	  
	booktabs // a nicer version of tables
	substitute("<" "$<$" "main" "")
	fragment
	replace
	;

# delimit cr
eststo clear
	
	
******************************************************************

set more off
local file inspector_chances_oprobit

** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "This table examines how treatment assignment may have affected inspectors' subjective assessments of their chances of being selected for future schemes."
file write tablenote " We report ordered probit regressions, where treatment is measured with randomization results."
file write tablenote " The unit of observation is a circle, as defined at the time of randomization."
file write tablenote " Responses in columns 1 and 2 were coded on a 5 point probablity scale, with 1 indicating 'Not likely at all' and 5 indicating 'Definitely.'"
file write tablenote " Responses in columns 3 and 4 were coded on a 3 point probability scale, with 1 indicating less chance, 2 indicating same chance, and 3 indicating higher chance."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Standard errors are clustered by a robust partition of circles,"
file write tablenote " i.e. the group of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 

cap log close
