/*******************************************************************************
SATISFACTION CORRELATIONS
Correlation of Satisfaction and Corruption Variables

* Panel A - Correlation with own response
* Panel B - Correltaion with others in circle

Kunal Mangal
April 8 2014

*******************************************************************************/
version 12
clear all
set more off

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

********************************************
* Correlation Matrix 

# delimit ;
local corr_vars
	tax_satisfied
	tax_quality
	norm_tax_payment_total
	tax_corruption
	;
#delimit cr

use "Coded Data/survey_coded_data.dta", clear

keep if _select_c_xw == 0
keep if SEC9 == 0

g norm_tax_payment_total = tax_payment_total / GARV

* g leaveout estimator
foreach X of var `corr_vars' {
	bys circle_id: egen tt1 = total(`X') if `X' != .
	bys circle_id: egen t1 = mean(tt1)
	by circle_id: egen ttc1 = count(`X') if `X' != .
	bys circle_id: egen tc1 = mean(ttc1)
	g lo_`X' = (t1 - `X')/(tc1-`X') if `X' != .
	replace lo_`X' = (t1)/(tc1) if `X' == .
	drop t1 tc1 tt1 ttc1

}

label var tax_satisfied "Satisfaction"
label var tax_quality "Quality"
label var norm_tax_payment_total "Bribes (normalized)"
label var tax_corruption "\specialcell{Perception of \\ Corruption}"

label var lo_tax_satisfied "Satisfaction"
label var lo_tax_quality "Quality"
label var lo_norm_tax_payment_total "Bribes (normalized)"
label var lo_tax_corruption "Perception of Corruption"


* Own correlations
reg tax_satisfied tax_quality norm_tax_payment_total tax_corruption , cluster(circle_id)
eststo own1
qui sum tax_satisfied if e(sample) == 1 
estadd scalar ysumm = `r(mean)'


reg tax_quality tax_satisfied norm_tax_payment_total tax_corruption , cluster(circle_id)
eststo own2
qui sum tax_quality if e(sample) == 1 
estadd scalar ysumm = `r(mean)'


reg norm_tax_payment_total tax_quality tax_satisfied tax_corruption , cluster(circle_id)
eststo own3
qui sum norm_tax_payment_total if e(sample) == 1 
estadd scalar ysumm = `r(mean)'


reg tax_corruption tax_quality tax_satisfied norm_tax_payment_total, cluster(circle_id)
eststo own4
qui sum tax_corruption if e(sample) == 1 
estadd scalar ysumm = `r(mean)'



reg tax_satisfied  lo_tax_satisfied lo_tax_quality lo_norm_tax_payment_total lo_tax_corruption , cluster(circle_id)
eststo other1
qui sum tax_satisfied if e(sample) == 1 
estadd scalar ysumm = `r(mean)'

reg tax_quality lo_tax_satisfied lo_tax_quality lo_norm_tax_payment_total lo_tax_corruption , cluster(circle_id)
eststo other2
qui sum tax_quality  if e(sample) == 1 
estadd scalar ysumm = `r(mean)'

reg norm_tax_payment_total lo_tax_satisfied lo_tax_quality lo_norm_tax_payment_total lo_tax_corruption , cluster(circle_id)
eststo other3
qui sum norm_tax_payment_total if e(sample) == 1 
estadd scalar ysumm = `r(mean)'

reg tax_corruption lo_tax_satisfied lo_tax_quality lo_norm_tax_payment_total lo_tax_corruption , cluster(circle_id)
eststo other4
qui sum tax_corruption if e(sample) == 1 
estadd scalar ysumm = `r(mean)'



** TeX OUTPUT - 

# delimit ;
esttab own1 own2 own3 own4
	using "${TABLE_OUTPUT}/tex/input/satisfaction_correlation_input.tex" , 
	keep(tax_satisfied tax_quality norm_tax_payment_total tax_corruption)
	
	b(%6.0g)
	se(%6.0g)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	order(tax_satisfied tax_quality norm_tax_payment_total tax_corruption)
	
	/*mtitles("\specialcell{Self- \\ reported \\ Tax \\ Payment}"
	  "\specialcell{Bribe \\ Payment}"
	  "\specialcell{Frequency \\ of Bribe \\ Payment}"
	  "\specialcell{Perception \\ of \\ Corruption}"
	  "\specialcell{Total \\ payment \\ to tax \\ dept. \\ (Tax + \\ Bribe)}") // Column headings*/

	refcat(
	  tax_satisfied "\emph{Panel A: Correlations with own response}", nolabel
	)
	
	stats(N,
	  labels("N")
	  fmt("%12.0f")
	)
	//nonumbers // No column numbers
	label // Use Variable Labels	
	nonotes
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

esttab other1 other2 other3 other4
	using "${TABLE_OUTPUT}/tex/input/satisfaction_correlation_input.tex" , 
	keep(lo_tax_satisfied lo_tax_quality lo_norm_tax_payment_total lo_tax_corruption)

	b(%6.0g)
	se(%6.0g)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	/*mtitles("\specialcell{Self- \\ reported \\ Tax \\ Payment}"
	  "\specialcell{Bribe \\ Payment}"
	  "\specialcell{Frequency \\ of Bribe \\ Payment}"
	  "\specialcell{Perception \\ of \\ Corruption}"
	  "\specialcell{Total \\ payment \\ to tax \\ dept. \\ (Tax + \\ Bribe)}") // Column headings*/

	refcat(
	  lo_tax_satisfied  "\emph{Panel B: Correlations with others in circle}", nolabel
	)
	
	stats(N ysumm,
	  labels("N" "Mean of dependent variable")
	  fmt("%12.0f" "%12.3f")
	)
	
	nonumbers // No column numbers
	nomtitles
	
	label // Use Variable Labels	
	nonotes
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	append
	;
	
	
# delimit cr

* WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off
local file satisfaction_correlation

/*
** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "Property-level OLS regressions. Panel A reports regressions of dependent variable on"
file write tablenote " own response of independent variables. Panel B reports regressions of dependent variable"
file write tablenote " on circle-level leave-one-out estimators of independent variables. Bribes are normalized by GARV"
file write tablenote " to be comparable within circle. Satisfaction, Quality, and Perception of Corruption are measured"
file write tablenote " on 5-point Likert scaled, normalized to a [0,1] interval."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Standard errors are clustered by robust partition,"
file write tablenote " the partition of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote
*/

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
  
 *********************************************************************************
 
