/*
	Crosswalk to Randomization
	
	Arguments
	This do file takes two arguments [qnow] and [ynow]. These together identify the quarter / fiscal year for which
	we want crosswalked outcomes data. That is, it takes admin data from that quarter and expresses it in terms of 
	the 482 randomization circles
	
	This do file works in 3 steps:
		1. Generates transition matrices
		2. Applies transition matrices in order to generate crosswalked values
		3. Handles special cases

	Summary of each step
	
	Step 1 -
	The keys file identifies robust partitions (the set of circles that contain a common set of properties)
	from one quarter to the next. First we loop through the keys file to determine which circles need to be
	crosswalked. For those that do, we generate a transition matrix and save it as a datafile for use later.
	The transition matrix is such that multiplying it with a vector of historical data produces the crosswalked
	values for that robust partition. In some cases, the transition matrix has values either below 0 or above 1
	-- these values are rounded up (down) to 0 (or 1).
	
	Step 2 - 
	Start with data from the quarterly data from the ynow/qnow quarter. Then go backward in time to randomization
	and apply appropriate transition matrices in succession.
	
	Step 3 - 
	There are two reasons to have special cases: First, a particular weakness of this method is that when 
	circles merge and split again into their original form some values may get unnecessarily crosswalked and
	we would need to undo that. The second reason is that some circles exist in between Q1 2012 and Q4 2011 and
	so we need to crosswalk them specifically.
	
	---
	
	Globals referenced here are defined in Master Compile.do
*/

clear all
set more off

cap cd "${PAKTAX_ANALYSIS}"

set trace off
pause off

*****************************************

args ynow qnow

* Make dirs
cap mkdir "Data/Cleaned Data/Administrative Data/Crosswalk/Transition Matrices/"
cap mkdir "Data/Cleaned Data/Administrative Data/Crosswalk/Transition Matrices/To Randomization"			

cap mkdir "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly"
cap mkdir "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization"

// Step 1: Generate transition matrices
forval y = `ynow'(-1)2012 {
	forval q = 4(-1)1 {
		if (`y' < `ynow') | (`y' == `ynow' & `q' <= `qnow') {

			// Previous quarter and year in a way that loops around
			local y2 = `y' - floor(1 / `q')
			local q2 = `q' - 1 + (4 * floor(1 / `q'))
			
			cap mkdir "Data/Cleaned Data/Administrative Data/Crosswalk/Transition Matrices/To Randomization//FY`y' Q`q'/"
			
			* Pull keys for the starting quarter
			use "Data/Cleaned Data/Administrative Data/Crosswalk/Keys/`y'_q`q'_keys.dta", clear
			keep if size_robust_partition > 1
			
			tempfile keys
			save `keys'
			
			qui count
			local N = `r(N)'
			
			* Skip if there's nothing to crosswalk
			if `N' == 0 continue
			
			* Loop through each of the robust partitions, and generate transitions
			forval i = 1/`N' {
				use `keys', clear
				keep in `i'
				
				levelsof robust_partition, local(rp)
							
				levelsof key2, local(circles) clean
				global circles = "`circles'"
				noi di "${circles}"
											
				* Make transition matrix in terms of total
				foreach x in t {

					clear
				
					* Generate transition matrix
					do "Data/Do Files/Cleaning/Administrative Data/Crosswalk/Make Transition Matrix.do" `q' `y' `x' 1
					
					clear
					svmat T
					
					local truncate = 0
					
					* Truncate
					foreach var of varlist T* {
					
						count if `var' < 0 | (`var' > 1 & `var' < .)
						local n = `r(N)'
							
						* In case of truncation, save the not-truncated copies and add to truncated list
						if `n' > 0 & `truncate' == 0 {
							save "Data/Cleaned Data/Administrative Data/Crosswalk/Transition Matrices/To Randomization/FY`y' Q`q'/rp`rp'_`x'_notrounded.dta", replace
								
							preserve
								clear
								set obs 1
								gen fyear = `y'
								gen qtr = `q'
								gen rp = `rp'
								gen margin = "t"
								gen direction = "To Randomization"
								
								cap append using "Data/Cleaned Data/Administrative Data/Crosswalk/Truncated"
								duplicates drop
								save "Data/Cleaned Data/Administrative Data/Crosswalk/Truncated", replace
							restore

							local truncate = 1

						}
					
					
						replace `var' = 0 if `var' < 0
						replace `var' = 1 if `var' > 1 & `var' < .
					}
					
					save "Data/Cleaned Data/Administrative Data/Crosswalk/Transition Matrices/To Randomization/FY`y' Q`q'/rp`rp'_`x'.dta", replace				
				}
			
			}
					
		}
	}
}



//Step 2: Apply transition matrices in order to the data
use "Data/Cleaned Data/Administrative Data/Quarterly/FY`ynow' Q`qnow'/FY`ynow' Q`qnow'.dta", clear
keep circle_id net_dem* gross_dem* recov_tot*
sort circle_id
save "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", replace

mata
	real matrix function crosswalk(T) {
		a0 = st_data(., 2)
		a0_xw = T * a0
		return(a0_xw)
	}
end

mata
	void savevalues(a0_xw, V) {
		updatevar = V
		st_addvar("double", updatevar)
		st_store(., updatevar, a0_xw)
	}
end

forval y = `ynow'(-1)2012 {
	forval q = 4(-1)1 {
		if (`y' < `ynow') | (`y' == `ynow' & `q' <= `qnow') {

			// Previous quarter and year in a way that loops around
			local y2 = `y' - floor(1 / `q')
			local q2 = `q' - 1 + (4 * floor(1 / `q'))
			
			
			* Pull keys for the starting quarter
			use "Data/Cleaned Data/Administrative Data/Crosswalk/Keys/`y'_q`q'_keys.dta", clear
			keep if size_robust_partition > 1
			
			tempfile keys
			save `keys'
			
			qui count
			local N = `r(N)'
			
			* Skip if there's nothing to crosswalk
			if `N' == 0 continue
			
			* Loop through each of the robust partitions, and generate transitions
			forval i = 1/`N' {
				use `keys', clear
				keep in `i'

				levelsof key2, local(circles) clean
				pause
				
				levelsof key1, local(circles2) clean
				levelsof robust_partition, local(rp) clean
				
				use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", clear
				keep if inlist(circle_id, `circles')
				keep circle_id net_dem* gross_dem* recov_tot*
				sort circle_id
				tempfile data
				save `data'
				
				foreach x in c a {
					use "Data/Cleaned Data/Administrative Data/Crosswalk/Transition Matrices/To Randomization/FY`y' Q`q'/rp`rp'_t.dta", clear
					mkmat T*, matrix(T)
					mata : T = st_matrix("T")
						
					clear
						
					foreach var in net_dem gross_dem recov_tot {

						use `data'
						keep circle_id `var'_`x'
						sort circle_id
						mata : a0_xw = crosswalk(T)					
						mata : a0_xw
						
						use "Data/Cleaned Data/Administrative Data/Quarterly/FY`y2' Q`q2'/FY`y2' Q`q2'.dta", clear
						keep if inlist(circle_id, `circles2')
						keep circle_id
						sort circle_id
						
						mata : savevalues(a0_xw, "`var'_`x'")
						
						tempfile overwrite
						save `overwrite'
						
						// Overwrite with new data
						use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", clear
						merge 1:1 circle_id using `overwrite', update replace nogenerate
						save "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", replace

						
					}
				}

			}
		}
	}
}


// Special cases


// Special case #1 -- 809300 needs to be merged

use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", clear
keep if inlist(circle_id, 809301, 809302)
keep circle_id net_dem* gross_dem* recov_tot*
tempfile data
save `data'
				
clear
set obs 1
gen T1 = 1
gen T2 = 1

mkmat T*, matrix(T)
mata : T = st_matrix("T")
						
clear

foreach x in c a {					
	foreach var in net_dem gross_dem recov_tot {

		use `data'
		keep circle_id `var'_`x'
		mata : a0_xw = crosswalk(T)					
		mata : a0_xw
						
		clear
		set obs 1
		gen circle_id = 809300
						
		mata : savevalues(a0_xw, "`var'_`x'")
		
		tempfile overwrite
		save `overwrite'
		
		use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", clear
		merge 1:1 circle_id using `overwrite', update replace nogenerate
		save "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", replace
						
	}
}

// Special case #2 -- Undo crosswalk for 611900 and 611902

use "Data/Cleaned Data/Administrative Data/Quarterly/FY`ynow' Q`qnow'/FY`ynow' Q`qnow'.dta", clear
keep circle_id net_dem* gross_dem* recov_tot*
keep if inlist(circle_id, 611900, 611902)

tempfile overwrite
save `overwrite'

use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", clear
merge 1:1 circle_id using `overwrite', update replace nogenerate
save "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", replace

// 612200, 612300

if (`ynow' == 2013 & `qnow' >= 3) | (`ynow' > 2013) {

	use "Data/Cleaned Data/Administrative Data/Quarterly/FY`ynow' Q`qnow'/FY`ynow' Q`qnow'.dta", clear
	keep circle_id net_dem* gross_dem* recov_tot*
	keep if inlist(circle_id, 612200, 612300)

	tempfile overwrite
	save `overwrite'

	use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", clear
	merge 1:1 circle_id using `overwrite', update replace nogenerate
	save "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", replace

}

// 801200, 801400

if (`ynow' >= 2013) {

	use "Data/Cleaned Data/Administrative Data/Quarterly/FY`ynow' Q`qnow'/FY`ynow' Q`qnow'.dta", clear
	keep circle_id net_dem* gross_dem* recov_tot*
	keep if inlist(circle_id, 801200, 801400)

	tempfile overwrite
	save `overwrite'

	use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", clear
	merge 1:1 circle_id using `overwrite', update replace nogenerate
	save "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", replace

}

// 802400

if (`ynow' > 2013) | (`ynow' == 2013 & `qnow' >= 2) {

	use "Data/Cleaned Data/Administrative Data/Quarterly/FY`ynow' Q`qnow'/FY`ynow' Q`qnow'.dta", clear
	keep circle_id net_dem* gross_dem* recov_tot*
	keep if inlist(circle_id, 802400)

	tempfile overwrite
	save `overwrite'

	use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", clear
	merge 1:1 circle_id using `overwrite', update replace nogenerate
	save "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", replace

}

// 800511
// -- need to merge back together

// Case 1
if (`ynow' == 2014 & `qnow' <= 2) | (`ynow' == 2013 & `qnow' >= 2) {

	use "Data/Cleaned Data/Administrative Data/Quarterly/FY`ynow' Q`qnow'/FY`ynow' Q`qnow'.dta", clear
	keep if inlist(circle_id, 800521, 800522)
	keep circle_id net_dem* gross_dem* recov_tot*
	tempfile data
	save `data'
				
	clear
	set obs 1
	gen T1 = 1
	gen T2 = 1

	mkmat T*, matrix(T)
	mata : T = st_matrix("T")
							
	clear

	foreach var in net_dem gross_dem recov_tot {
		foreach x in c a {					
			use `data'
			keep circle_id `var'_`x'
			mata : a0_xw = crosswalk(T)					
			mata : a0_xw
							
			clear
			set obs 1
			gen circle_id = 800511
							
			mata : savevalues(a0_xw, "`var'_`x'")
			
			tempfile overwrite
			save `overwrite'
			
			use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", clear
			merge 1:1 circle_id using `overwrite', update replace nogenerate
			save "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", replace
		}				
	}

}

// Case 2
if (`ynow' == 2014 & `qnow' > 2) | (`ynow' > 2014) {

	use "Data/Cleaned Data/Administrative Data/Quarterly/FY`ynow' Q`qnow'/FY`ynow' Q`qnow'.dta", clear
	keep if inlist(circle_id, 800521, 800523, 800524)
	keep circle_id net_dem* gross_dem* recov_tot*
	tempfile data
	save `data'
				
	clear
	set obs 1
	gen T1 = 1
	gen T2 = 1
	gen T3 = 1
	
	mkmat T*, matrix(T)
	mata : T = st_matrix("T")
							
	clear

	foreach var in net_dem gross_dem recov_tot {
		foreach x in c a {					
			use `data'
			keep circle_id `var'_`x'
			mata : a0_xw = crosswalk(T)					
			mata : a0_xw
							
			clear
			set obs 1
			gen circle_id = 800511
							
			mata : savevalues(a0_xw, "`var'_`x'")
			
			tempfile overwrite
			save `overwrite'
			
			use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", clear
			merge 1:1 circle_id using `overwrite', update replace nogenerate
			save "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", replace
		}				
	}

}


// 508400 and 508500
if (`ynow' >= 2014) {

	use "Data/Cleaned Data/Administrative Data/Quarterly/FY`ynow' Q`qnow'/FY`ynow' Q`qnow'.dta", clear
	keep circle_id net_dem* gross_dem* recov_tot*
	keep if inlist(circle_id, 508400, 508500)

	tempfile overwrite
	save `overwrite'

	use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", clear
	merge 1:1 circle_id using `overwrite', update replace nogenerate
	save "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", replace

}


// 1000300, 1000400, 1000900
// Undo crosswalk for property transfer at beginning of Q1 2012

if (`ynow' >= 2012)  {
	use "Data/Cleaned Data/Administrative Data/Quarterly/FY`ynow' Q`qnow'/FY`ynow' Q`qnow'.dta", clear
	keep circle_id net_dem* gross_dem* recov_tot*
	keep if inlist(circle_id, 1000300, 1000400, 1000900)

	tempfile overwrite
	save `overwrite'

	use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", clear
	merge 1:1 circle_id using `overwrite', update replace nogenerate
	save "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", replace
}


* Clean up
insheet using "Data/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", comma clear
keep rand_circle_id
rename rand_circle_id circle_id 
duplicates drop

merge 1:1 circle_id using "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta"
qui count if _merge == 3

// We're missing data for 503200 for these quarters
if `ynow' == 2012 & `qnow' > 1 {
	assert `r(N)' == 481
	drop if _merge == 2
	drop _merge
}
else {
	assert `r(N)' == 482
	keep if _merge == 3
	drop _merge
}

foreach var in gross_dem net_dem recov_tot {
	replace `var'_c = round(`var'_c)
	replace `var'_a = round(`var'_a)
	replace `var'_t = `var'_c + `var'_a
}

drop if missing(circle_id)

save "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`ynow'_q`qnow'.dta", replace
