/*********************************************************
	Make Keys
	
	----------------------------------
	
	Keys are the identifiers that link a robust partition
	to the circles that compose it. A robust partition is
	the set of circles that share a common set of properties.
	
	Robust partitions are defined quarter by quarter. A
	robust partition is the set of circles that merge
	or split together.
	
	The keys file is used to identify which circles to
	crosswalk.
	
*********************************************************/

clear all
set more off

cap cd "${PAKTAX_ANALYSIS}"

****************************************************

********************************
* SET QUARTER OF LATEST ANALYSIS
if "$ynow" == "" {
	display "Enter the latest fiscal year: " _request(ynow)
	}
if "$qnow" == "" {
	display "Enter the latest quarter: " _request(qnow)
	}
local ynow = $ynow
local qnow = $qnow
********************************

* Make directory if necessary
cap mkdir "Data/Cleaned Data/"
cap mkdir "Data/Cleaned Data/Administrative Data/"
cap mkdir "Data/Cleaned Data/Administrative Data/Crosswalk"
cap mkdir "Data/Cleaned Data/Administrative Data/Crosswalk/Keys"

forval y = 2008 / `ynow' {
	forval q = 1 / 4 {
		if (`y' < `ynow') | (`y' == `ynow' & `q' < `qnow') {
		
			// Next quarter and next year in a way that loops around
			local q2 = mod(`q', 4) + 1
			local y2 = `y' + int(`q' / 4)
			
			* Generate 
			insheet using "Data/Raw Data/Administrative Data/Crosswalk//`y2'_q`q2'_transition.csv", comma clear
			
			reshape long q`q2'_`y2'_circle_id, i(q`q'_`y'_circle_id) j(splits)
			drop if q`q2'_`y2'_circle_id == .

			* Group robust partitions
			* -- Use an iterative technique to find them. (Same as the technique for cluster_c)
			egen circle1 = group(q`q'_`y'_circle_id)
			egen circle2 = group(q`q2'_`y2'_circle_id)

			bys circle2: egen i1 = max(circle1)
			bys circle1: egen i2 = max(i1)

			bys circle2: egen i3 = max(i2)
			bys circle1: egen i4 = max(i3)

			egen robust_partition = group(i4)
			
			drop circle1 circle2 i*

			//Make sure that split circles are sorted in the same order, and that there are no duplicate splits
			egen num_splits = max(splits), by(q`q'_`y'_circle_id)

			drop splits
			sort q`q'_`y'_circle_id q`q2'_`y2'_circle_id
			bys q`q'_`y'_circle_id : gen splits = _n

			reshape wide q`q2'_`y2'_circle_id, i(q`q'_`y'_circle_id) j(splits)
			duplicates tag q`q2'_`y2'_circle_id*, generate(duplicate_splits)
			assert duplicate_splits == 0 if num_splits > 1
			drop duplicate_splits

			drop num_splits
			
			// Reshape back to long after duplicates check
			reshape long
			drop splits
			drop if missing(q`q2'_`y2'_circle_id)
			
			tempfile rp
			save `rp'
		
			* Generate key1 (starting circles)
			drop q`q2'_`y2'_circle_id
			
			duplicates drop
			drop if missing(q`q'_`y'_circle_id) // New circles
			
			rename q`q'_`y'_circle_id circle
			
			bys robust_partition (circle): gen j = _n
			egen size_robust_partition1 = max(j), by(robust_partition)
			
			reshape wide circle, i(robust_partition) j(j)
			
			tostring circle*, replace
			foreach var of varlist circle* {
				replace `var' = "" if `var' == "."
			}
			
			egen key1 = concat(circle*), p(",")
			
			gen last_letter = substr(key,length(key), length(key)+1)
			qui count if last_letter == ","
			local trailing = `r(N)'
			
			while `trailing' > 0 {
				replace key = substr(key, 1, length(key)-1) if last_letter == ","
				drop last_letter
				
				gen last_letter = substr(key,length(key), length(key)+1)
				qui count if last_letter == ","
				local trailing = `r(N)'
			}
			
			tempfile key
			save `key'
			
			* Generate key2
			use `rp', clear
			
			drop if missing(q`q'_`y'_circle_id) // New circles
			drop q`q'_`y'_circle_id
			
			duplicates drop

			rename q`q2'_`y2'_circle_id circle
			
			bys robust_partition (circle): gen j = _n
			egen size_robust_partition2 = max(j), by(robust_partition)

			reshape wide circle, i(robust_partition) j(j)
			
			tostring circle*, replace
			foreach var of varlist circle* {
				replace `var' = "" if `var' == "."
			}
			
			egen key2 = concat(circle*), p(",")
			
			gen last_letter = substr(key,length(key), length(key)+1)
			qui count if last_letter == ","
			local trailing = `r(N)'
			
			while `trailing' > 0 {
				replace key = substr(key, 1, length(key)-1) if last_letter == ","
				drop last_letter
				
				gen last_letter = substr(key,length(key), length(key)+1)
				qui count if last_letter == ","
				local trailing = `r(N)'
			}
			
			merge 1:1 robust_partition using `key'
			assert _merge == 3
			drop _merge
			
			gen change = .
			replace change = 0 if size_robust_partition1 == 1 & size_robust_partition2 == 1
			replace change = 1 if size_robust_partition1 > 1 & size_robust_partition2 == 1
			replace change = 2 if size_robust_partition1 == 1 & size_robust_partition2 > 1
			replace change = 3 if size_robust_partition1 > 1 & size_robust_partition2 > 1
			
			cap label define change 0 "No change" 1 "Merge" 2 "Split" 3 "Complex"
			label values change change
			
			egen size_robust_partition = rowmax(size_robust_partition1 size_robust_partition2)
			drop size_robust_partition1 size_robust_partition2
			
			* Clean up
			
			keep key1 key2 robust_partition size_robust_partition change
			order key1 key2 robust_partition size_robust_partition change
			
			label var key1 "FY `y' Q`q' Circles"
			label var key2 "FY `y2' Q`q2' Circles"
			label var robust_partition "Robust Partition ID"
			label var size_robust_partition "Maximum number of circles involved in transition"
			label var change "Type of crosswalk"
			
			saveold "Data/Cleaned Data/Administrative Data/Crosswalk/Keys//`y2'_q`q2'_keys.dta", replace
			
		}
	}
}
